global raw "$path/raw_data"
global work "$path/working_data"
global figure "$path/figures"

	use  "$work/adult_12pre.dta", clear  
	drop if age_12<18
	 
	* people with local hukou 
	gen local=0 
	replace local=1 if hukou_add>0 & hukou_add<4
	replace local=. if hukou_add<=0 | hukou_add>10 
	keep if local==1 

 	lab var nrsp_pt "enrolled in NRPS by 2012, NOT receiving pensions"
	lab var nrsp_rc "enrolled in NRPS by 2012, AND receiving pensions"
	lab var nrsp_pre "enrolled in NRPS in FIRST wave"
	lab var nrsp_post "enrolled in NRPS in SECOND wave"
	lab var nrsp "enrolled in NRPS by 2012, May or May Not receiving pensions"

	* hukou & urban & NRPS-enrollment  
	drop if hukou!=1 //only samples with Agricultural Hukou 

	**  county coverage indicator 
	replace nrsp_pre=0 if mis==1 
	replace nrsp_post=0 if mis==1 
	bysort countyid: egen pre_ctN=sum(nrsp_pre) 
	bysort countyid: egen post_ctN=sum(nrsp) 
	bysort countyid: gen ct_N=_N 
	bysort countyid: gen ct_n=_n 
	gen cvrt_pre=pre_ctN/ct_N 
	gen cvrt_post=post_ctN/ct_N 
	
	duplicates drop countyid, force 

	////////////////////////////////////////////// 
	** Merge with County List in the Final Sample 
	merge 1:1 countyid using "$work/CountyInFinalSample"
	keep if _m==3 
	drop _m 
	drop if FamilyInCounty<2
	count 
	 
	** Exclude urban counties in Shanghai/Beijing/Chongqing/Tianjin 
	drop if provcd==11 | provcd==12 |  provcd==31 | provcd==50 
	
	** Exclude special cases (change in County/Qu definition)
	drop if countyid==127
	drop if countyid==12

	** merge with Pilot Year Info & Identifiers  
	merge 1:1 countyid using "$raw_data/cfps_county_pilot"
 	drop if _m==2
 	drop _m 	
	
	** keep counties with at least N respondents 
	hist ct_N,  freq width(20) xtitle("Number of Adult Respondents", size(medlarge)) lcolor(white) ytitle("Number of Counties", size(medlarge)) lw(.1) title("CFPS", margin(b=5)) xlab(, labsize(med)) ylab(, labsize(med))
 	graph export "$figure/CountyN_CFPS.pdf", replace 
 	keep if ct_N>=20 

** Define Treatment Status 
	
*1. THRESHOLD (participants)= 3 
	gen ct_nrsp=. 
	replace ct_nrsp=1 if pre_ctN<3 & post_ctN>2    
		//group1: no yes (treated)
	replace ct_nrsp=2 if pre_ctN<3 & post_ctN<3
		//group2: no no 
	replace ct_nrsp=3 if pre_ctN>2 & post_ctN>2 
		//group3: yes yes (control)
	replace ct_nrsp=4 if pre_ctN>2 & post_ctN<3
		//yes no 
	gen treat1=. 
	replace treat1=1 if ct_nrsp==1 
	replace treat1=0 if ct_nrsp==3
 	ren ct_nrsp cover_type1
	
*2. THRESHOLD (participants)= 5
	gen ct_nrsp=. 
	replace ct_nrsp=1 if pre_ctN<5 & post_ctN>4    
		//group1: no yes (treated)
	replace ct_nrsp=2 if pre_ctN<5 & post_ctN<5
		//group2: no no 
	replace ct_nrsp=3 if pre_ctN>4 & post_ctN>4 
		//group3: yes yes (control)
	replace ct_nrsp=4 if pre_ctN>4 & post_ctN<5
		//yes no 
	gen treat2=. 
	replace treat2=1 if ct_nrsp==1 
	replace treat2=0 if ct_nrsp==3
 	ren ct_nrsp cover_type2
	
*3. THRESHOLD (participants)= 5 & PROPORTION = 5%
	gen ct_nrsp=. 
	replace ct_nrsp=1 if (pre_ctN<5 | cvrt_pre<.05) & (post_ctN>4 | cvrt_post>=.05) 
		//group1: no yes (treated)
	replace ct_nrsp=2 if (pre_ctN<5 | cvrt_pre<.05) & (post_ctN<4 | cvrt_post<.05)
		//group2: no no 
	replace ct_nrsp=3 if (pre_ctN>4 | cvrt_pre>=.05) & (post_ctN>4 | cvrt_post>=.05) 
		//group3: yes yes (control)
	replace ct_nrsp=4 if (pre_ctN>4 | cvrt_pre>=.05) & (post_ctN<4 | cvrt_post<.05)
		//yes no 
	gen treat3=. 
	replace treat3=1 if ct_nrsp==1 
	replace treat3=0 if ct_nrsp==3
	ren ct_nrsp cover_type3
	
*4. Yes (N>9) No (N<5)
	gen ct_nrsp=. 
	replace ct_nrsp=1 if pre_ctN<5 & post_ctN>9    
		//group1: no yes (treated)
	replace ct_nrsp=2 if pre_ctN<5 & post_ctN<5
		//group2: no no 
	replace ct_nrsp=3 if pre_ctN>9 & post_ctN>9  
		//group3: yes yes (control)
	replace ct_nrsp=4 if pre_ctN>9 & post_ctN<5
		//group 4: yes no 
	gen treat4=. 
	replace treat4=1 if ct_nrsp==1 
	replace treat4=0 if ct_nrsp==3
 	ren ct_nrsp cover_type4

 	lab define treat 1 "Treated (No-Yes)" 0 "Control (Yes-Yes)" 
	lab define Treat 1 "Treated (No-Yes)" 0 "Control (No-No)"
	lab define cover 1 "No-Yes" 2 "No-No" 3 "Yes-Yes" 
	
	forvalues i=1/4{
	lab values treat`i' treat 
	lab values cover_type`i' cover
	gen Treat`i'= (cover_type`i'==1)
	replace Treat`i'=. if cover_type`i'>2
	lab values Treat`i' Treat 
	}

	keep provcd countyid countycd countyname county_py pilot_yr ct_N treat* cover*  Treat* cvrt_* 

	twoway (hist cvrt_post if treat2==0, frac width(.1) lw(.4) start(0) lcolor(white)) (hist cvrt_post if treat2==1, frac width(.1) lcolor(red) color(none) lw(.3) start(0)) , xtitle("Participation Rate in 2012", size(medlarge)) ytitle("Fraction of Counties", size(medlarge)) title("CFPS", margin(b=5)) xsca(r(0 1)) xlab(0(.2)1, labsize(med)) ylab(0(.05).2, labsize(medsmall)) legend(order(1 "Control" 2 "Treatment") ring(0) col(1) pos(1) nobox region(color(none)) size(small)) ysca(r(0 .22))
	graph display, xsize(10) ysize(9)
 	graph export "$figure/CoverRate_CFPS.pdf", replace 

	
	save "$work/CFPS_treatment.dta", replace 

