global raw_data "$path/raw_data"
global working_data "$path/working_data"
global out_files "$path/out_files"

**==============================================**
**       Respondent and Spouse Information      **
**==============================================**
use "$raw_data/demographic_background.dta", clear 

ren rgender gender
replace gender =. if gender != 1 & gender != 2
merge 1:1 ID using "$raw_data/weight.dta"
drop if _merge!=3
drop _merge
destring iyear imonth, replace
replace ba002_2=6.5 if ba002_2==0 
gen btime=ba002_1+(ba002_2-0.5)/12
gen stime=iyear+(imonth-0.5)/12
gen age=stime-btime
replace age=ba004+0.5 if age==.
ren ba002_2 birth_mt 
ren ba002_1 birth_yr 

//education 
gen edu_yr=bd006-bd005 
replace edu_yr=0 if mi(bd005) & mi(bd006)
bysort communityID: egen st_yr=median(bd005) 
bysort communityID: egen fi_yr=median(bd006)
bysort communityID: egen me_edyr=median(edu_yr) 
replace edu_yr=bd006-st_yr if mi(bd005) & !mi(bd006) 
replace edu_yr=fi_yr-bd005 if !mi(bd005) & mi(bd006) 
replace edu_yr=me_edyr if edu_yr<0 
replace edu_yr=me_edyr if edu_yr>=35
replace edu_yr=edu_yr+bd008 if !mi(bd008) 
replace edu_yr=. if edu_yr<0 

gen hukou=bc001
replace hukou=. if hukou>3
label variable hukou "=1 agri, =2 nonagri, =3 unified"
bysort communityID: egen mhukou=median(bc001)
replace hukou=mhukou if hukou==. 
replace hukou=2 if hukou==1.5 
drop if bc005>3 //local hukou 

keep ID householdID communityID gender age edu_yr hukou iyear imonth birth_yr birth_mt
bysort householdID: gen rs_N=_N
bysort householdID: egen mage=mean(age)
bysort householdID: egen mxage=max(age)
bysort householdID: egen mnage=mean(age)

bysort householdID: egen mhukou=mean(hukou)
bysort householdID: egen medyr=mean(edu_yr)
lab var medyr "respondent and spouse's mean education year"
lab var mage "respondent and spouse's mean age"
lab var mxage "respondent and spouse's max age"
lab var mnage "respondent and spouse's min age"
lab var mhukou "respondent and spouse's mean hukou"
gen ID11=ID 

merge 1:1 ID using "$raw_data/work_retirement_and_pension.dta" , keepusing(fn080) keep(match) nogene

merge 1:1 ID using "$working_data/pension11.dta" , keepusing(nrsp)  
drop if _m==2 
drop _m

save "$working_data/parents11.dta", replace 

use "$raw_data/Demographic_Background13.dta", clear 
gen id_tm=substr(ID,11,2)
gen hh_tm=substr(householdID,1,9)
gen ID11=hh_tm+id_tm 
ren ba000_w2_3 gender13
keep ID11 gender 
bysort ID11: gen rpt=_n 
keep if rpt==1 
drop rpt 
merge 1:1 ID11 using "$working_data/parents11.dta"
drop if _merge==1 
replace gender=gender13 if gender==. & !mi(gender13)
bysort householdID: egen gender_m=mean(gender)
replace gender=gender13 if gender!=gender13 & gender_m==1 & gender!=. 
replace gender=gender13 if gender!=gender13 & gender_m==2 & gender!=. 
drop _merge gender_m 
save "$working_data/parents11.dta", replace 

**==============================================**
**             Children Information             **
**==============================================**
use "$raw_data/family_information.dta", clear 

keep householdID ID communityID cb001 cb009 cd003* cd004* cb049_* cb051_1_* cb051_2_* cb053_* 	cb055_* cb058_* cb059_* cb060_* cb061_* cb062_* cb065_* cb066_* cb067_* cb068_* cb069_* cb070_* cb071_* cb080_* 
forvalues i=15/25{
gen cb049_`i'_=.
gen cb051_1_`i'_=.
gen cb051_2_`i'_=.
gen cb053_`i'_=.
gen cb055_`i'_=.
gen cb058_`i'_=.
gen cb065_`i'_=.
gen cd003_`i'_=.
gen cd004_`i'_=.
}
forvalues i=11/25{
gen cb060_`i'_=.
gen cb068_`i'_=.
}
forvalues i=11/22{
gen cb066_`i'_=.
}
forvalues i=24/25{
gen cb066_`i'_=.
}
forvalues i=10/25{
gen cb059_`i'_ =.
}
gen cb059_7_ =.
forvalues i=15/22{
gen cb067_`i'_=.
}
forvalues i=24/25{
gen cb067_`i'_=.
}
forvalues i=16/22{
gen cb069_`i'_ =.
}
gen cb069_24_ =.
forvalues i=15/16{
gen cb070_`i'_=.
}
gen cb070_24_=.
gen cb070_19_=.
forvalues i=21/22{
gen cb070_`i'_=.
}
forvalues i=11/16{
gen cb071_`i'_=.
}
forvalues i=18/22{
gen cb071_`i'_=.
}
gen cb071_24_=.

forvalues i=1/25{
ren cb049_`i'_  gender`i' 
ren cb051_1_`i'_  birth_yr`i'
ren cb051_2_`i'_  birth_mt`i'
ren cb053_`i'_  where`i'
ren cb055_`i'_ hukou`i'
ren cb058_`i'_ atsch`i'
ren cb065_`i'_ N_son`i'
ren cb067_`i'_ N_dau`i'
ren cd003_`i'_ see`i' 
ren cd004_`i'_ con`i'
ren cb059_`i'_  sch_lv`i'
ren cb066_`i'_ N_adson`i'
ren cb068_`i'_ N_addau`i'
ren cb071_`i'_ occu`i'
ren cb070_`i'_ work`i'
ren cb069_`i'_ tinc`i'
ren cb060_`i'_ h_schlv`i'
}
reshape long gender birth_yr birth_mt where hukou atsch sch_lv h_schlv  N_son N_dau N_adson N_addau tinc work occu see con , i(ID) j(child_id)
drop cb053* cb061* cb062* cb080* 
ren cb001 bio_child
ren cb009 adopt_child
replace sch_lv=. if sch_lv>26
replace h_schlv=. if h_schlv>13 
egen edu_g=cut(sch_lv), at(0,1,7,11,17,23,25)
egen edu_gr=group(edu_g)
egen edu_g1=cut(h_schlv), at(1,2,4,5,6,8,12)
egen edu_gr1=group(edu_g1)
label define edu_lv 1"Illiterate" 2"Primary Unfinished" 3"Primary Finished" 4"Middle Finished" 5"High Finished" 6"College and above"
label values edu_gr1 edu_lv
tab edu_gr1,m
ren edu_gr1 edulv_fn
replace edu_gr=edu_gr+1 if !mi(edu_gr)
replace edulv_fn=edu_gr if mi(edulv_fn) & !mi(edu_gr)
tab edulv_fn,m
drop edu_g edu_gr edu_g1  
lab var edulv_fn "finished education level"
lab var N_addau "# adult daughters"
lab var N_adson "# adult sons"
gen chN=N_dau+N_son
gen adchN=N_addau+N_adson 
lab var chN "# of children"
lab var adchN "# of adult children"

egen mis=rowmin(tinc-edulv_fn)
tab mis,m
drop if mis==.
egen mis1=rowmax(tinc-edulv_fn)
tab mis1,m
drop if mis1==0 
drop mis* 

merge m:1 ID using "$raw_data/weight.dta", keepusing(iyear imonth)
destring iyear imonth, replace
drop if _merge!=3
drop _merge 
replace birth_mt=. if birth_mt>13 
replace birth_yr=. if birth_yr>2015 

replace birth_mt=6.5 if birth_mt==0 | birth_mt==. 
gen btime=birth_yr+(birth_mt-0.5)/12 
gen stime=iyear+(imonth-0.5)/12
gen age=stime-btime
lab var see "frequency of seeing each other"
lab var con "frequency of contacting each other"
lab var atsch "=1, still at school"
merge 1:1 householdID child_id using "$working_data/transfer11.dta"
keep if _merge==3
drop _merge 
drop iyear imonth btime stime 
drop lvar* gft* 
tab ctp if where==. 
drop if mi(age) & mi(work) & mi(edu)
drop birth* 

* residence information 
ren where residence 
replace residence=0 if mi(residence)
lab define res 0"Same Household" 1"Same Household but Independent" 2"Same Yard/Apartment" 3"Same Village/Neighborhood" ///
	4"Same County/City" 5"Same Province" 6"Another Province" 7"Abroad"
lab values residence res 
replace residence=. if residence==.r | residence==.d 
tab residence, m  

drop sch_lv h_schlv 
order N_son N_dau N_addau N_adson , aft(adchN)
ren tinc income 
order age, bef(income)
replace ctp=0 if ctp==. 
replace ptc=0 if ptc==. 
replace gctp=0 if gctp==. 
replace ptgc=0 if ptgc==. 
save "$working_data/children11_pre.dta", replace 

** include parents' information 
use "$working_data/parents11.dta", clear 

sort householdID 
foreach x in age edu_yr hukou{
gen `x'_1=`x' if gender==2 
gen `x'_2=`x' if gender==1 
bysort householdID: egen `x'_m=mean(`x'_1)
bysort householdID: egen `x'_f=mean(`x'_2)
}
bys householdID: egen NRPS_N=total(nrsp)

keep householdID age* hukou* edu* rs_N NRPS_N
bysort householdID: gen rpt=_n 
keep if rpt==1 
drop rpt 
keep age_m age_f edu_yr_f edu_yr_m hukou_m hukou_f rs_N householdID NRPS_N 

merge 1:m householdID using "$working_data/children11_pre.dta"
keep if _merge==3
drop _merge
lab var rs_N "=1, respondent live alone,=2 with spouse"
label variable income "total income level"
label variable work "work or not"
label variable occu "type of occupation"
label variable see "how often parents see child "
label variable con "how often parents contact child "
label variable ctp "transfer from child to parents"
label variable gctp "transfer from grandchild to parents"
label variable ptgc "transfer from parents to grandchildren"
label variable ptgc "transfer from parents to grandchild"
label variable ptc "transfer from parents to child"
label variable gc_hrs "childcare hours"
label variable N_son "number of son"
label variable N_dau "number of daughter"
label variable N_adson "number of adult son"
label variable N_addau "number of adult daughter"
label variable chN "number of children"
label variable adchN "number of nonadult children"
label variable residence "residence of child"
label variable hukou "hukou of child"
label variable age "age of child"
gen male=1 if gender==1 
replace male=0 if gender==2
lab var male "=1, child is male"
drop gender 

foreach x in work hukou N_son N_dau see con atsch N_addau N_adson{
replace `x'=. if `x'==.d 
replace `x'=. if `x'==.e 
replace `x'=. if `x'==.r
}
save "$working_data/children11.dta", replace
capture erase "$working_data/parents_temp.dta"


use "$raw_data/fwealth.dta", clear 
keep householdID fwealth fawealth fasset_rs
bysort householdID: gen rpt=_n 
keep if rpt==1 
drop rpt 
merge 1:m householdID using "$working_data/children11.dta"
drop if _merge!=3
drop _merge 
ren child_id childID 
order *ID, bef(fwealth)
lab var fwealth "total wealth of family"
lab var fawealth "average wealth of family"
lab var fasset_rs "asset of parents (respondent&spouse)"
label variable age_m "age of mother"
label variable age_f "age of father"
label variable edu_yr_m "school year of mother"
label variable edu_yr_f "school year of father"
label variable hukou_m "hukou of mother"
label variable hukou_f "hukou of father"
label variable childID "order ID of child "
ren con contact 
ren see visit 

ren income tinc 
gen yinc= tinc
replace yinc=0 if    tinc==1
replace yinc=2000/3 if    tinc==2 
replace yinc=2000+(5000-2000)/3 if tinc==3
replace yinc=5000+(10000-5000)/3 if tinc==4
replace yinc=10000+(20000-10000)/3 if tinc==5
replace yinc=20000+(50000-20000)/3 if tinc==6
replace yinc=50000+(100000-50000)/3 if tinc==7
replace yinc=100000+(150000-100000)/3 if tinc==8
replace yinc=150000+(200000-150000)/3  if tinc==9
replace yinc=200000+(300000-200000)/3 if tinc==10
replace yinc=300000 if tinc==11
replace yinc=. if yinc>300000

save "$working_data/children11.dta", replace


**=================================================**
****              parents samples                ****
**=================================================** 

use "$working_data/transfer11.dta", clear 
bysort householdID: egen CTP=sum(ctp)
bysort householdID: egen PTC=sum(ptc)
bysort householdID: egen GCTP=sum(gctp)
bysort householdID: egen PTGC=sum(ptgc)
bysort householdID: egen CHCR=sum(gc_hrs)
keep if child_id==1  
drop child_id ctp ptc ptgc gctp gc_hrs gft_rc gft_gv gft_rcyr gft_gvyr
drop ID 

merge 1:m householdID using "$working_data/parents11.dta"
drop if _merge!=3
drop _merge 
sort householdID ID
order lvar1_r lvar2_r lvar1_s lvar2_s CTP PTC GCTP PTGC CHCR, aft( rs_N)
order ID11, aft(ID)
lab var lvar1_r "living arrangement preference (respondent)"
lab var lvar2_r "living arrangement preference (respondent)"
lab var lvar1_s "living arrangement preference (spouse)"
lab var lvar2_s "living arrangement preference (spouse)"
save "$working_data/parents11.dta", replace 

use "$working_data/children11.dta", clear 
bysort householdID: gen rpt=_n
gen apart=(residence>0)
gen cores=(residence==0)

bys householdID: egen N_apartch=sum(apart)  
bys householdID: egen N_coresch=sum(cores)
bys householdID: gen N_ch=_N
bys householdID: egen N_mch=sum(male)
gen N_fmch=N_ch-N_mch 
bys householdID: egen mnage_ch=min(age)
bys householdID: egen mxage_ch=max(age)

bysort householdID: egen minc_ch=mean(yinc) 
bysort householdID: egen mage_ch=mean(age) 

keep if rpt==1
keep householdID N_ch minc_ch mage_ch N_apartch N_coresch N_mch N_fmch mnage_ch mxage_ch   

merge 1:m householdID using "$working_data/parents11.dta" 
replace N_ch=0 if _merge==2 
drop _merge 
drop birth* iyear imonth 
order minc mage_ch N_ch, aft(medyr)

label variable lvar1_r "living arrangement attitude"
label variable lvar2_r "living arrangement attitude"
label variable lvar1_s "living arrangement attitude"
label variable lvar2_s "living arrangement attitude"
label variable CTP "total ctp "
label variable PTC "total ptc"
label variable GCTP "total gctp "
label variable PTGC "total ptgc"
label variable CHCR "total childcare hours"
label variable minc_ch "mean year income of children"
label variable mage_ch "mean age of children"
label variable N_ch "total # of children"
lab var age "age"
lab var rs_N "=2 with spouse"
lab var edu_yr "schooling years"
sort householdID ID
drop mage mxage mnage mhukou medyr
save "$working_data/parents11.dta", replace 

use "$raw_data/fwealth.dta", clear 
keep householdID fwealth fawealth fasset_rs
bysort householdID: gen rpt=_n 
keep if rpt==1 
drop rpt 
merge 1:m householdID using "$working_data/parents11.dta"
keep if _merge==3
drop _merge 
order *ID ID*, bef(fwealth)
lab var fwealth "total wealth of family"
lab var fawealth "average wealth of family"
ren fn080 oldcare 
ren nrsp NRPS 
save "$working_data/parents11.dta", replace 
