
global raw_data "$path/raw_data"
global working_data "$path/working_data"
global out_files "$path/out_files"

**==============================================**
**       Respondent and Spouse Information      **
**==============================================**

use "$raw_data/Demographic_Background13.dta", clear 
gen id_tm=substr(ID,11,2)
gen hh_tm=substr(householdID,1,9)
gen ID11=hh_tm+id_tm 
drop hh_tm id_tm
bysort ID11: gen rpt1=_N
drop if rpt1==2
drop rpt1
ren ID ID13 
ren ID11 ID 
ren ba002_1 ba002_1_  
ren ba002_2 ba002_2_
merge 1:1 ID using "$raw_data/demographic_background.dta", keepusing(ba002_2 ba002_1)
drop if _merge==2
label define merge 1 "not matched with 2011" 3"matched with 2011"
lab values _merge merge 
ren _merge merge 
ren ba002_2 birth_mt 
ren ba002_1 birth_yr 
ren ba001_w2_1 birth_rg

drop if zbc005>3 
drop if bc005_w2_1==1 & mi(zbc005)

merge 1:1 ID using "$working_data/parents11.dta", keepusing(gender)
drop if _merge==2 
drop _merge 
ren gender gender11 
drop ID 
ren ID13 ID 
bysort householdID: gen rs_N=_N
ren ba000_w2_3 gender
tab gender,m
bysort householdID: egen gen_tem=min(gender)
replace gender=3-gen_tem if rs_N==2 & mi(gender)
tab gender,m
drop gen_tem
bysort householdID: egen gender_m=mean(gender)
tab gender_m rs_N 
replace gender=gender11 if gender!=gender11 & gender11!=. & rs_N==1 
replace gender=gender11 if gender!=gender11 & gender_m==1 & rs_N==2 & gender11!=. 
replace gender=gender11 if gender!=gender11 & gender_m==2 & rs_N==2 & gender11!=. 
drop gender_m
bysort householdID: egen gender_m=mean(gender)
tab gender_m rs_N 
replace gender=2 if gender11==1 & gender_m==1 & rs_N==2 
drop gender_m
drop gender11
merge 1:1 ID using "$raw_data/Weights13.dta" 
drop if _merge!=3
drop _merge
destring iyear imonth, replace
replace birth_yr=ba002_1_ if birth_rg==2 
replace birth_mt=ba002_2_ if birth_rg==2 
replace birth_yr=ba002_1_ if birth_yr==. 
replace birth_mt=ba002_2_ if birth_mt==. 
replace birth_mt=6.5 if birth_mt==0 
gen btime=birth_yr+(birth_mt-0.5)/12
gen stime=iyear+(imonth-0.5)/12
gen age=stime-btime
replace age=ba004+0.5 if age==. 

//education 
gen edu_yr=bd006-bd005 
tab edu_yr,m 
replace edu_yr=0 if mi(bd005) & mi(bd006)
bysort communityID: egen st_yr=median(bd005)  
bysort communityID: egen fi_yr=median(bd006)
bysort communityID: egen me_edyr=median(edu_yr) 
replace edu_yr=bd006-st_yr if mi(bd005) & !mi(bd006) 
replace edu_yr=fi_yr-bd005 if !mi(bd005) & mi(bd006) 
replace edu_yr=me_edyr if edu_yr<0 
replace edu_yr=me_edyr if edu_yr>=35
replace edu_yr=edu_yr+bd008 if !mi(bd008) 
tab edu_yr,m 
set more off 
replace edu_yr=. if edu_yr<0 

gen hukou=bc001
replace hukou=. if hukou>3
label variable hukou "=1 agri, =2 nonagri, =3 unified"
bysort communityID: egen mhukou=median(bc001)
replace hukou=mhukou if hukou==. 
replace hukou=2 if hukou==1.5 

keep ID householdID communityID rs_N gender age edu_yr hukou iyear imonth birth_rg

bysort householdID: egen mage=mean(age)
bysort householdID: egen mxage=max(age)
bysort householdID: egen mnage=min(age)
bysort householdID: egen mhukou=mean(hukou)
bysort householdID: egen medyr=mean(edu_yr)
lab var medyr "respondent and spouse's mean education year"
lab var mage "respondent and spouse's mean age"
lab var mxage "respondent and spouse's max age"
lab var mnage "respondent and spouse's min age"
lab var mhukou "respondent and spouse's mean hukou"
drop birth_rg

merge 1:1 ID using "$raw_data/Work_Retirement_and_Pension13.dta" , keepusing (fn097*) keep(match) nogene
ren fn097 oldcare  

merge 1:1 ID using "$working_data/pension13.dta" , keepusing(nrsp)  
drop if _m==2 
drop _m

save "$working_data/parents13.dta", replace 


** CHILDREN SAMPLE
use "$working_data/transfer13.dta", clear 
ren child_id childID 
merge 1:1 ID childID using "$raw_data/Child13.dta" 
egen mis=rowmax(ctp rctp ptc rptc gctp rgctp ptgc rptgc gc_hrs) 
drop if _merge==2 
drop if _merge==1 & mis==0 
drop hhmem_id mis _merge 
ren cb051_1 birth_yr
ren cb051_2 birth_mt
tab cb053
ren cb055 hukou
ren cb058 atsch
ren cb059 sch_lv
ren cb070 work
ren cb071 occupation
ren cb060 h_schlv
ren cb053 residence
replace residence=resi-1 

lab define res 0"Same Household" 1"Same Household but Independent" 2"Same Yard/Apartment" ///
	3"Same Village/Neighborhood" 4"Same County/City" 5"Other" 6"Abroad"
lab values residence res 
replace residence=0 if mi(residence) 

egen edu_g=cut(sch_lv), at(0,1,7,11,17,23,25)
egen edu_gr=group(edu_g)
egen edu_g1=cut(h_schlv), at(1,2,4,5,6,8,12)
egen edu_gr1=group(edu_g1)
label define edu_lv 1"Illiterate" 2"Primary Unfinished" 3"Primary Finished" 4"Middle Finished" 5"High Finished" 6"College and above"
label values edu_gr1 edu_lv
tab edu_gr1,m
ren edu_gr1 edulv_fn
replace edu_gr=edu_gr+1 if !mi(edu_gr)
replace edulv_fn=edu_gr if mi(edulv_fn) & !mi(edu_gr)
tab edulv_fn,m
drop edu_g edu_gr edu_g1 sch_lv h_schlv 
lab var edulv_fn "finished education level"

merge m:m householdID using "$raw_data/Weights13.dta" 
drop if _merge!=3
drop _merge
destring iyear imonth, replace

replace birth_mt=6.5 if birth_mt==0 
gen btime=birth_yr+(birth_mt-0.5)/12
gen stime=iyear+(imonth-0.5)/12
gen age_o=stime-btime
replace age_o=0 if age_o<0 
gen age_r=round(age_o)
ren age_o age_det
replace age_det=age if mi(age_det) & !mi(age)
replace age_det=age if age_r!=age & !mi(age_r)
drop age_r  
lab var age_det "calculated detailed age"
ren cat catg
ren cb063 marital 
ren cb069 income
ren cb065 chN
ren cb066 nadchN
local transfer ctp rctp ptc rptc gctp rgctp ptgc rptgc gc_hrs
local demo age*  resi gender catg alive hukou marit work occup inc chN nadchN edu* atsch 
keep *ID `transfer' `demo'
lab var rptc "regular ptc"
lab var rctp "regular ctp"
lab var gc_hrs "childcare hours" 
order HHmem version, bef(ctp)

ren income tinc 
gen yinc= tinc
replace yinc=0 if    tinc==1 
replace yinc=2000/3 if    tinc==2 
replace yinc=2000+(5000-2000)/3 if tinc==3
replace yinc=5000+(10000-5000)/3 if tinc==4
replace yinc=10000+(20000-10000)/3 if tinc==5
replace yinc=20000+(50000-20000)/3 if tinc==6
replace yinc=50000+(100000-50000)/3 if tinc==7
replace yinc=100000+(150000-100000)/3 if tinc==8
replace yinc=150000+(200000-150000)/3  if tinc==9
replace yinc=200000+(300000-200000)/3 if tinc==10
replace yinc=300000 if tinc==11
replace yinc=. if yinc>300000

save "$working_data/children13.dta", replace 

* Include parents' information 
use "$working_data/parents13.dta", clear 

foreach x in age edu_yr hukou{
gen `x'_1=`x' if gender==2 
gen `x'_2=`x' if gender==1 
bysort householdID: egen `x'_m=mean(`x'_1)
bysort householdID: egen `x'_f=mean(`x'_2)
}
bys householdID: egen NRPS_N=total(nrsp)

keep householdID age* hukou* edu* rs_N NRPS_N
bysort householdID: gen rpt=_n 
keep if rpt==1 
drop rpt 
keep age_m age_f edu_yr_f edu_yr_m hukou_m hukou_f rs_N householdID NRPS_N

merge 1:m householdID using "$working_data/children13.dta"
keep if _merge==3
drop _merge
order *ID, bef(rs_N)
lab var rs_N "=1, respondent live alone,=2 with spouse"
label variable ctp "transfer from child to parents"
label variable gctp "transfer from grandchild to parents"
label variable ptgc "transfer from parents to grandchildren"
label variable ptgc "transfer from parents to grandchild"
label variable ptc "transfer from parents to child"
label variable gc_hrs "childcare hours"
gen male=1 if gender==1 
replace male=0 if gender==2
lab var male "=1, child is male"
drop gender 
save "$working_data/children13.dta", replace 

use "$raw_data/fwealth13.dta", clear 
keep householdID fwealth  fasset_rs
bysort householdID: gen rpt=_n 
keep if rpt==1 
drop rpt 
merge 1:m householdID using "$working_data/children13.dta"
drop if _merge!=3
drop _merge 
order *ID, bef(fwealth)
drop ID 
lab var fwealth "total wealth of family"
lab var fasset_rs "asset of parents (respondent&spouse)"
label variable age_m "age of mother"
label variable age_f "age of father"
label variable edu_yr_m "school year of mother"
label variable edu_yr_f "school year of father"
label variable hukou_m "hukou of mother"
label variable hukou_f "hukou of father"
label variable childID "order ID of child "
lab var rgctp "regular transfer"
lab var rptgc "regular transfer"
drop if hukou_m==1.5 | hukou_f==1.5 
duplicates drop householdID childID, force 

save "$working_data/children13.dta", replace 


** Parents sample
use "$working_data/transfer13.dta", clear 
bysort householdID: egen CTP=sum(ctp)
bysort householdID: egen PTC=sum(ptc)
bysort householdID: egen GCTP=sum(gctp)
bysort householdID: egen PTGC=sum(ptgc)
bysort householdID: egen CHCR=sum(gc_hrs)
keep if child_id==1  
keep ID householdID CTP PTC GCTP PTGC CHCR 
drop ID 
merge 1:m householdID using "$working_data/parents13.dta"
drop if _merge!=3
drop _merge 
sort householdID ID
order CTP PTC GCTP PTGC CHCR, aft( rs_N)
drop imonth iyear 
save "$working_data/parents13.dta", replace 

use "$working_data/children13.dta", clear 
bysort householdID: gen rpt=_n 
bysort householdID: gen N_ch=_N 
bysort householdID: egen minc_ch=mean(yinc) 
bysort householdID: egen mage_ch=mean(age) 
bysort householdID: egen N_mch=sum(male)
gen N_fmch=N_ch-N_mch 

bysort householdID: egen mnage_ch=min(age) 
bysort householdID: egen mxage_ch=max(age) 
gen cores=(residence==0)
gen apart=(residence>0)
bys householdID: egen N_coresch=sum(cores)
bys householdID: egen N_apartch=sum(apart)

keep if rpt==1
keep householdID N_ch N_mch N_fmch minc_ch mage_ch mnage_ch mxage_ch N_cores N_apart

merge 1:m householdID using "$working_data/parents13.dta" 
replace N_ch=0 if _merge==2 
drop _merge 
order minc mage_ch N_ch, aft(medyr)

label variable CTP "total ctp "
label variable PTC "total ptc"
label variable GCTP "total gctp "
label variable PTGC "total ptgc"
label variable CHCR "total childcare hours"
label variable minc_ch "mean year income of children"
label variable mage_ch "mean age of children"
label variable N_ch "total # of children"
lab var age "age"
lab var rs_N "=2 with spouse"
lab var edu_yr "schooling years"
sort householdID ID
drop mage mxage mnage mhukou medyr
save "$working_data/parents13.dta", replace 

use "$raw_data/fwealth13.dta", clear 
keep householdID fwealth fasset_rs
bysort householdID: gen rpt=_n 
keep if rpt==1 
drop rpt 
merge 1:m householdID using "$working_data/parents13.dta" 
keep if _merge==3
drop _merge 
order *ID ID*, bef(fwealth)
lab var fwealth "total wealth of family"
ren nrsp NRPS 

save "$working_data/parents13.dta", replace 
