
global raw_data "$path/raw_data"
global working_data "$path/working_data"
global figure "$path/figures"

**==============================================**
**        PENSION COVERAGE IDENTIFICATION       **
**==============================================**

**===========================**
**     PENSION IN 2011       **
**===========================**
use "$raw_data/work_retirement_and_pension.dta", clear 

gen rec_p=(fn001==1)
replace rec_p=0 if fn001==2
replace rec_p=. if fn001>2
gen sfp_rc=(fn002s1==1)
gen cmp_rc=(fn002s2==2)
gen rrp_rc=(fn002s3==3)
gen rsp_rc=(fn002s4==4)
gen urp_rc=(fn002s5==5)
gen sop_rc=(fn002s6==6)
gen otp_rc=(fn002s7==7)
gen gvp_er=(fn024==1)
gen fbp_er=(fn024==2)

//pensions enrolled 
gen enr_p=(fn038==1)
replace enr_p=0 if fn038==2
replace enr_p=. if fn038>2
gen sfp_er=(fn039s1==1)
gen cmp_er=(fn039s2==2)
gen rrp_er=(fn039s3==3)
gen rsp_er=(fn039s4==4)
gen urp_er=(fn039s5==5)
gen otp_er=(fn039s6==6)

//NRSP participation 
gen nrsp=(fn071==1)
replace nrsp=0 if fn071==2 
replace nrsp=. if fn071>2 

//reasons not participating
gen rs_nav=( fn072s1==1)
gen rs_mn=( fn072s2==2)
gen rs_3=( fn072s3==3)
gen rs_low=( fn072s4==4)
gen rs_5=( fn072s5==5)
gen rs_6=( fn072s6==6)
gen rs_7=( fn072s7==7)
gen rs_otp=( fn072s8==8)
gen rs_9=( fn072s9==9)
gen par_yr= fn073_1
gen par_mt= fn073_2
ren fn080 osp
gen nrsp_rc=1 if fn077==1 
replace nrsp_rc=0 if fn077==2 
tab nrsp_rc,m 

gen oth_pen=0
foreach i in `i' sfp cmp rrp rsp urp sop {
replace oth_pen=1 if `i'_rc==1 
}
foreach i in `i' sfp cmp rrp rsp urp gvp fbp {
replace oth_pen=1 if `i'_er==1 
}
tab oth_pen nrsp,m 
ren fn079 mt_pay
keep ID householdID communityID  rec_p- oth_pen mt_pay nrsp_rc

//Hukou information 
merge 1:1 ID using "$raw_data/demographic_background.dta", keepusing(bb001 bc001 bc002 bc005)
drop if _merge!=3
drop _merge
gen huk_lcm=(bc005==2) 
gen huk_lct=(bc005==1 | bc005==2)
replace huk_lcm=1 if bc005==1 & bb001==1 
replace huk_lct=1 if bc005==1 & bb001==1 
replace huk_lct=1 if bc005==1 & bb001==2
lab var huk_lcm "=1, hukou is in local community"
lab var huk_lct "=1, hukou is in local county"

// Interview Time 
merge m:m householdID using "$raw_data/weight.dta", keepusing(iyear imonth)
drop if _merge!=3
drop _merge 

merge m:m communityID using "$raw_data/psu.dta", keepusing(urban_nbs)
drop if _merge!=3
drop _merge 
bysort ID: gen rpt=_N
tab rpt
bysort ID: gen rpt1=_n 
keep if rpt1==1 
drop rpt rpt1 
gen ID11=ID 
save "$working_data/pension11-pre.dta", replace 

//COUNTY-LEVEL TREATMENT 
keep if huk_lct==1 
ren bc001 hukou
drop bc002 bc005
tab nrsp hukou
keep if hukou==1 
gen countyID=substr(communityID, 1,6)
bysort countyID: egen nrsp_N=sum(nrsp)
tab nrsp_N
bysort countyID: gen ct_N=_N 
gen nrsp_cvr=nrsp_N/ct_N
bysort countyID: egen amt_pay=median(mt_pay)
lab var amt_pay "county-median level of monthly payment of NRSP"
lab var nrsp_cvr "county coverage rate of NRSP"
lab var nrsp_N "total amount of NRSP participants"
bysort countyID: egen nav_N=sum(rs_nav)

save "$working_data/pension11.dta", replace 
  
bysort countyID: gen ct_id=_n 
keep if ct_id==1 
keep countyID nrsp_N ct_N nrsp_cvr amt_pay nav_N
save "$working_data/treat11.dta", replace 


**===========================**
**     PENSION IN 2013       **
**===========================**
use "$raw_data/work_retirement_and_pension13.dta", clear 

gen oth_pen=0
forvalues i=1/8{
replace oth_pen=1 if fn001_w2s`i'==`i'
}
forvalues i=10/12{
replace oth_pen=1 if fn001_w2s`i'==`i'
}
tab oth_pen fn001_w2s9,m

//NRSP participation 
gen nrsp=(fn001_w2s9==9)
replace nrsp=1 if fn069_w2==1 
replace nrsp=0 if fn069_w2==2 
replace nrsp=. if fn069_w2>2 

//reasons not participating
gen rs_nav=( fn070_w2s1==1)
gen rs_mn=( fn070_w2s2==2)
gen rs_3=( fn070_w2s3==3)
gen rs_low=( fn070_w2s4==4)
gen rs_5=( fn070_w2s5==5)
gen rs_6=( fn070_w2s6==6)
gen rs_7=( fn070_w2s7==7)
gen rs_otp=( fn070_w2s8==8)
gen rs_9=( fn070_w2s9==9)
gen par_yr= fn071_w2_1
gen par_mt= fn071_w2_2

ren fn097_w2 osp
forvalues i=1/11{
ren fn098_w2s`i' ch_rel`i'
}
//monthly payment 
ren fn077_w2 mt_pay
destring fn077_w2_bracketbracket_max fn077_w2_bracketbracket_min, replace 
replace mt_pay=fn077_w2_bracketbracket_min if mi(mt_pay)
ren fn079_w2 Emt_pay
destring fn079_w2_bracketbracket_min fn079_w2_bracketbracket_max, replace 
replace Emt_pay=. if Emt_pay<0

keep ID householdID communityID oth_pen nrsp rs_nav-par_mt osp ch_rel1-ch_rel11  mt_pay Emt_pay

save "$working_data/pension13.dta", replace 

//Hukou information
merge 1:1 ID using "$raw_data/demographic_background13.dta", keepusing(bb001 bb000_w2_1 bb000_w2_1_1 bc001 bc001_w2_1 bc005_w2_1  bc005)
drop if _merge!=3
drop _merge
gen id_tm=substr(ID,11,2)
gen hh_tm=substr(householdID,1,9)
gen ID11=hh_tm+id_tm 
drop hh_tm id_tm
bysort ID11: gen rpt=_n
bysort ID11: gen rpt1=_N
drop if rpt1==2 
drop rpt*
merge 1:1 ID11 using "$working_data/pension11-pre.dta", keepusing (huk_lcm huk_lct iyear imonth)
drop if _merge!=3
drop _merge 
ren iyear iyear11
ren imonth imonth11 

// Interview Time 
merge m:m householdID using "$raw_data/Weights13.dta", keepusing(iyear imonth)
drop if _merge!=3
drop _merge 
merge m:m communityID using "$raw_data/psu.dta", keepusing(urban_nbs)
drop if _merge!=3
drop _merge 
bysort ID: gen rpt=_N
tab rpt
bysort ID: gen rpt1=_n 
sort ID 
keep if rpt1==1 
drop rpt rpt1 

//COUNTY-LEVEL TREATMENT 
ren bc001 hukou 
tab nrsp hukou 
keep if hukou==1 
keep if huk_lct==1 
replace huk_lct=0 if bc005_w2_1==1 & bc005==4
replace huk_lct=0 if bc005_w2_1==1 & bc005==2 & bb001==3
replace huk_lct=0 if bc005_w2_1==1 & bc005==2 & bb001==4
keep if huk_lct==1 

gen countyID=substr(communityID, 1,6)
bysort countyID: egen nrsp_N=sum(nrsp)
bysort countyID: gen ct_N=_N 
gen nrsp_cvr=nrsp_N/ct_N 
bysort countyID: egen amt_pay=median(mt_pay)
bysort countyID: egen aEmt_pay=median(Emt_pay)
lab var amt_pay "county-median level of monthly payment of NRSP"
lab var nrsp_cvr "county coverage rate of NRSP"
lab var nrsp_N "total amount of NRSP participants"
lab var aEmt_pay "county-median level of expected monthly payment of NRSP"
bysort countyID: egen nav_N=sum(rs_nav)
save "$working_data/pension13.dta", replace 

** PENSION SHOCK IDENTIFICATION 

bysort countyID: gen ct_id=_n 
keep if ct_id==1 
keep countyID nrsp_N ct_N nrsp_cvr amt_pay aEmt_pay nav_N
ren nrsp_N nrsp_N13
ren ct_N ct_N13
ren nrsp_cvr nrsp_cvr13 
ren amt_pay amt_pay13
ren nav_N nav_N13 
save "$working_data/treat13.dta", replace 

merge 1:1 countyID using "$working_data/treat11.dta"
drop if _merge!=3
drop _merge 
order countyID ct_N nrsp_N ct_N13 nrsp_N13 nrsp_cvr nrsp_cvr13 nav_N nav_N13 amt_pay amt_pay13 aEmt_pay 
lab var nav_N "# saying nrsp not available"
lab var nav_N13 "# saying nrsp not available"
save "$working_data/treat_pre.dta", replace 

 
*****************************************************
** DEFINE TREATMENT STATUS 
*****************************************************

use "$working_data/treat_pre.dta", clear 

	** Only include county samples used in the final child sample 
	merge 1:1 countyID using "$working_data/ChildCountySample.dta"
	keep if _m==3 
	drop _m 
	egen ctN=rowmin(ct_N ct_N13)
	
	hist ctN,  freq width(10) xtitle("Number of Adult Respondents", size(medlarge)) lcolor(white) ytitle("Number of Counties", size(medlarge)) lw(.1) title("CHARLS", margin(b=5)) xsca(r(20 160)) xlab(20(20)160, labsize(med)) ylab(, labsize(med))
	graph display, xsize(10) ysize(9)
 	graph export "$figure/CountyN_CHARLS.pdf", replace 
	
	keep if ctN>=20 
 	
	ren nrsp_N pre_ctN
	ren nrsp_N13 post_ctN
	ren nrsp_cvr cvrt_pre
	ren nrsp_cvr13 cvrt_post

** 1. TREATMENT-1
* >>>>>> THRESHOLD(participants)= 3  <<<<<< * 

	gen ct_nrsp=. 
	replace ct_nrsp=1 if pre_ctN<3 & post_ctN>2    
		//group1: no yes (treated)
	replace ct_nrsp=2 if pre_ctN<3 & post_ctN<3
		//group2: no no 
	replace ct_nrsp=3 if pre_ctN>2 & post_ctN>2 
		//group3: yes yes (control)
	replace ct_nrsp=4 if pre_ctN>2 & post_ctN<3
		//yes no 
 	gen treat1=. 
	replace treat1=1 if ct_nrsp==1 
	replace treat1=0 if ct_nrsp==3
 	ren ct_nrsp cover_type1
		
** 2. TREATMENT-2 
* >>>>>> THRESHOLD(participants)= 5  <<<<<< * 
	gen ct_nrsp=. 
	replace ct_nrsp=1 if pre_ctN<5 & post_ctN>4    
		//group1: no yes (treated)
	replace ct_nrsp=2 if pre_ctN<5 & post_ctN<5
		//group2: no no 
	replace ct_nrsp=3 if pre_ctN>4 & post_ctN>4 
		//group3: yes yes (control)
	replace ct_nrsp=4 if pre_ctN>4 & post_ctN<5
		//yes no 
	gen treat2=. 
	replace treat2=1 if ct_nrsp==1 
	replace treat2=0 if ct_nrsp==3
		
	ren ct_nrsp cover_type2


* >>>>>> 3. THRESHOLD(participants)= 5 & PROPORTION = 5%  <<<<<< * 
	gen ct_nrsp=. 
	replace ct_nrsp=1 if (pre_ctN<5 | cvrt_pre<.05) & (post_ctN>4 | cvrt_post>=.05) 
		//group1: no yes (treated)
	replace ct_nrsp=2 if (pre_ctN<5 | cvrt_pre<.05) & (post_ctN<4 | cvrt_post<.05)
		//group2: no no 
	replace ct_nrsp=3 if (pre_ctN>4 | cvrt_pre>=.05) & (post_ctN>4 | cvrt_post>=.05) 
		//group3: yes yes (control)
	replace ct_nrsp=4 if (pre_ctN>4 | cvrt_pre>=.05) & (post_ctN<4 | cvrt_post<.05)
		//yes no 
	gen treat3=. 
	replace treat3=1 if ct_nrsp==1 
	replace treat3=0 if ct_nrsp==3
		
	ren ct_nrsp cover_type3

* >>>>>> 4. Covered if N>9 & Not Covered if N<5  <<<<<< * 
	gen ct_nrsp=. 
	replace ct_nrsp=1 if pre_ctN<5 & post_ctN>9    
		//group1: no yes (treated)
	replace ct_nrsp=2 if pre_ctN<5 & post_ctN<5
		//group2: no no 
	replace ct_nrsp=3 if pre_ctN>9 & post_ctN>9  
		//group3: yes yes (control)
	replace ct_nrsp=4 if pre_ctN>9 & post_ctN<5
		//group 4: yes no 
	gen treat4=. 
	replace treat4=1 if ct_nrsp==1 
	replace treat4=0 if ct_nrsp==3
 	ren ct_nrsp cover_type4

	lab define treat 1 "Treated (No-Yes)" 0 "Control (Yes-Yes)" 
	lab define Treat 1 "Treated (No-Yes)" 0 "Control (No-No)"
	lab define cover 1 "No-Yes" 2 "No-No" 3 "Yes-Yes" 
	
	forvalues i=1/4{
	lab values treat`i' treat 
	lab values cover_type`i' cover
	gen Treat`i'= (cover_type`i'==1)
	replace Treat`i'=. if cover_type`i'>2
	lab values Treat`i' Treat 
 	}


	keep countyID treat*  ct_N cover_type*  Treat* cvrt_post cvrt_pre
	
	twoway (hist cvrt_post if treat2==0, frac width(.1) lw(.4) start(0) lcolor(white)) (hist cvrt_post if treat2==1, frac width(.1) lcolor(red) color(none) lw(.3) start(0)) , xtitle("Participation Rate in 2013", size(medlarge)) ytitle("Fraction of Counties", size(medlarge)) title("CHARLS", margin(b=5)) xsca(r(0 1)) xlab(0(.2)1, labsize(med)) ylab(0(.05).2, labsize(medsmall)) legend(order(1 "Control" 2 "Treatment") ring(0) col(1) pos(11) nobox region(color(none)) size(small)) ysca(r(0 .22))
	graph display, xsize(10) ysize(9)
 	graph export "$figure/CoverRate_CHARLS.pdf", replace 
	
	save "$working_data/treat.dta", replace 


